@@ -2,9 +2,9 @@ OC.L10N.register(
     "admin_migrate",
     {
     "Export data" : "Flytja út gögn",
-    "All system files and user data" : "Allar kerfis skrá og notanda gögn",
-    "Only system files" : "Aðeins kerfis skrár",
-    "Only user data" : "Aðeins notanda gögn",
+    "All system files and user data" : "Allar kerfisskrár og gögn notanda",
+    "Only system files" : "Aðeins kerfisskrár",
+    "Only user data" : "Aðeins notandagögn",
     "Export" : "Flytja út"
 },
 "nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
