@@ -4,13 +4,13 @@ OC.L10N.register(
     "Document was shared" : "Dokumenti u nda",
     "User %s shared quick document %s with you." : "Përdoruesi %s ndau me ju dokumentin e shpejtë %s.",
     "My pad" : "Blloku im",
-    "Settings" : "Parametra",
-    "Pad Title" : "Titulli i bllokut",
-    "Open" : "Hap",
-    "Share with" : "Nda me",
-    "Share" : "Nda",
-    "Etherpad service URL" : "URL e shërbimit Etherpad",
-    "Username" : "Përdoruesi",
-    "Save" : "Ruaj"
+    "Settings" : "Rregullime",
+    "Pad Title" : "Titull Blloku",
+    "Open" : "Hape",
+    "Share with" : "Ndajeni me",
+    "Share" : "Ndaje",
+    "Etherpad service URL" : "URL shërbimi Etherpad",
+    "Username" : "Emër përdoruesi",
+    "Save" : "Ruaje"
 },
 "nplurals=2; plural=(n != 1);");
