@@ -2,9 +2,9 @@ OC.L10N.register(
     "user_migrate",
     {
     "Export" : "Flytja út",
-    "Something went wrong while the export file was being generated" : "Eitthvað fór úrskeðis við gerð skráar til útflutning",
+    "Something went wrong while the export file was being generated" : "Eitthvað fór úrskeiðis við gerð útflutningsskráar",
     "An error has occurred" : "Villa kom upp",
-    "Account Export/Import" : "Flytja reikning út/inn",
+    "Account Export/Import" : "Flytja aðgangsreikning út/inn",
     "Import" : "Flytja inn"
 },
 "nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
